@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
-
 DOCUMENTATION = r"""
 ---
 module: business_sda_virtual_network_summary_info
 short_description: Information module for Business Sda Virtual Network Summary Info
 description:
-- This module represents an alias of the module business_sda_virtual_network_summary_v1_info
+  - This module represents an alias of the module business_sda_virtual_network_summary_v1_info
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,25 +18,20 @@ options:
     type: dict
   siteNameHierarchy:
     description:
-    - SiteNameHierarchy query parameter. Complete fabric siteNameHierarchy Path.
+      - SiteNameHierarchy query parameter. Complete fabric siteNameHierarchy Path.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for SDA GetVirtualNetworkSummaryV1
-  description: Complete reference of the GetVirtualNetworkSummaryV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-virtual-network-summary
+  - name: Cisco DNA Center documentation for SDA GetVirtualNetworkSummaryV1
+    description: Complete reference of the GetVirtualNetworkSummaryV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-virtual-network-summary
 notes:
-  - SDK Method used are
-    sda.Sda.get_virtual_network_summary_v1,
-
-  - Paths used are
-    get /dna/intent/api/v1/business/sda/virtual-network/summary,
+  - SDK Method used are sda.Sda.get_virtual_network_summary_v1,
+  - Paths used are get /dna/intent/api/v1/business/sda/virtual-network/summary,
   - It should be noted that this module is an alias of business_sda_virtual_network_summary_v1_info
-
 """
-
 EXAMPLES = r"""
 - name: Get all Business Sda Virtual Network Summary Info
   cisco.dnac.business_sda_virtual_network_summary_info:
@@ -53,7 +45,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     siteNameHierarchy: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
