@@ -9,147 +9,184 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: openssl_pkcs12
 author:
-- Guillaume Delpierre (@gdelpierre)
+  - Guillaume Delpierre (@gdelpierre)
 short_description: Generate OpenSSL PKCS#12 archive
 description:
-    - This module allows one to (re-)generate PKCS#12.
-    - The module can use the cryptography Python library, or the pyOpenSSL Python
-      library. By default, it tries to detect which one is available, assuming none of the
-      I(iter_size) and I(maciter_size) options are used. This can be overridden with the
-      I(select_crypto_backend) option.
-    # Please note that the C(pyopenssl) backend has been deprecated in community.crypto x.y.0,
-    # and will be removed in community.crypto (x+1).0.0.
+  - This module allows one to (re-)generate PKCS#12.
+  - The module can use the cryptography Python library, or the pyOpenSSL Python library. By default, it tries to detect which
+    one is available, assuming none of the O(iter_size) and O(maciter_size) options are used. This can be overridden with
+    the O(select_crypto_backend) option.
 requirements:
-    - PyOpenSSL >= 0.15 or cryptography >= 3.0
-options:
-    action:
-        description:
-            - C(export) or C(parse) a PKCS#12.
-        type: str
-        default: export
-        choices: [ export, parse ]
-    other_certificates:
-        description:
-            - List of other certificates to include. Pre Ansible 2.8 this parameter was called I(ca_certificates).
-            - Assumes there is one PEM-encoded certificate per file. If a file contains multiple PEM certificates,
-              set I(other_certificates_parse_all) to C(true).
-        type: list
-        elements: path
-        aliases: [ ca_certificates ]
-    other_certificates_parse_all:
-        description:
-            - If set to C(true), assumes that the files mentioned in I(other_certificates) can contain more than one
-              certificate per file (or even none per file).
-        type: bool
-        default: false
-        version_added: 1.4.0
-    certificate_path:
-        description:
-            - The path to read certificates and private keys from.
-            - Must be in PEM format.
-        type: path
-    force:
-        description:
-            - Should the file be regenerated even if it already exists.
-        type: bool
-        default: false
-    friendly_name:
-        description:
-            - Specifies the friendly name for the certificate and private key.
-        type: str
-        aliases: [ name ]
-    iter_size:
-        description:
-            - Number of times to repeat the encryption step.
-            - This is not considered during idempotency checks.
-            - This is only used by the C(pyopenssl) backend. When using it, the default is C(2048).
-        type: int
-    maciter_size:
-        description:
-            - Number of times to repeat the MAC step.
-            - This is not considered during idempotency checks.
-            - This is only used by the C(pyopenssl) backend. When using it, the default is C(1).
-        type: int
-    passphrase:
-        description:
-            - The PKCS#12 password.
-            - "B(Note:) PKCS12 encryption is not secure and should not be used as a security mechanism.
-              If you need to store or send a PKCS12 file safely, you should additionally encrypt it
-              with something else."
-        type: str
-    path:
-        description:
-            - Filename to write the PKCS#12 file to.
-        type: path
-        required: true
-    privatekey_passphrase:
-        description:
-            - Passphrase source to decrypt any input private keys with.
-        type: str
-    privatekey_path:
-        description:
-            - File to read private key from.
-            - Mutually exclusive with I(privatekey_content).
-        type: path
-    privatekey_content:
-        description:
-            - Content of the private key file.
-            - Mutually exclusive with I(privatekey_path).
-        type: str
-        version_added: "2.3.0"
-    state:
-        description:
-            - Whether the file should exist or not.
-              All parameters except C(path) are ignored when state is C(absent).
-        choices: [ absent, present ]
-        default: present
-        type: str
-    src:
-        description:
-            - PKCS#12 file path to parse.
-        type: path
-    backup:
-        description:
-            - Create a backup file including a timestamp so you can get the original
-              output file back if you overwrote it with a new one by accident.
-        type: bool
-        default: false
-    return_content:
-        description:
-            - If set to C(true), will return the (current or generated) PKCS#12's content as I(pkcs12).
-        type: bool
-        default: false
-        version_added: "1.0.0"
-    select_crypto_backend:
-        description:
-            - Determines which crypto backend to use.
-            - The default choice is C(auto), which tries to use C(cryptography) if available, and falls back to C(pyopenssl).
-              If one of I(iter_size) or I(maciter_size) is used, C(auto) will always result in C(pyopenssl) to be chosen
-              for backwards compatibility.
-            - If set to C(pyopenssl), will try to use the L(pyOpenSSL,https://pypi.org/project/pyOpenSSL/) library.
-            - If set to C(cryptography), will try to use the L(cryptography,https://cryptography.io/) library.
-            # - Please note that the C(pyopenssl) backend has been deprecated in community.crypto x.y.0, and will be
-            #   removed in community.crypto (x+1).0.0.
-            #   From that point on, only the C(cryptography) backend will be available.
-        type: str
-        default: auto
-        choices: [ auto, cryptography, pyopenssl ]
-        version_added: 1.7.0
+  - PyOpenSSL >= 0.15, < 23.3.0 or cryptography >= 3.0
 extends_documentation_fragment:
-    - files
+  - ansible.builtin.files
+  - community.crypto.attributes
+  - community.crypto.attributes.files
+attributes:
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
+  safe_file_operations:
+    support: full
+  idempotent:
+    support: partial
+    details:
+      - The module is not idempotent if O(force=true).
+options:
+  action:
+    description:
+      - V(export) or V(parse) a PKCS#12.
+    type: str
+    default: export
+    choices: [export, parse]
+  other_certificates:
+    description:
+      - List of other certificates to include. Pre Ansible 2.8 this parameter was called O(ca_certificates).
+      - Assumes there is one PEM-encoded certificate per file. If a file contains multiple PEM certificates, set O(other_certificates_parse_all)
+        to V(true).
+      - Mutually exclusive with O(other_certificates_content).
+    type: list
+    elements: path
+    aliases: [ca_certificates]
+  other_certificates_content:
+    description:
+      - List of other certificates to include.
+      - Assumes there is one PEM-encoded certificate per item. If an item contains multiple PEM certificates, set O(other_certificates_parse_all)
+      - Mutually exclusive with O(other_certificates).
+    type: list
+    elements: str
+    version_added: "2.26.0"
+  other_certificates_parse_all:
+    description:
+      - If set to V(true), assumes that the files mentioned in O(other_certificates)/O(other_certificates_content) can contain more than one
+        certificate per file/item (or even none per file/item).
+    type: bool
+    default: false
+    version_added: 1.4.0
+  certificate_path:
+    description:
+      - The path to read certificates and private keys from.
+      - Must be in PEM format.
+      - Mutually exclusive with O(certificate_content).
+    type: path
+  certificate_content:
+    description:
+      - Content of the certificate file in PEM format.
+      - Mutually exclusive with O(certificate_path).
+    type: str
+    version_added: "2.26.0"
+  force:
+    description:
+      - Should the file be regenerated even if it already exists.
+    type: bool
+    default: false
+  friendly_name:
+    description:
+      - Specifies the friendly name for the certificate and private key.
+    type: str
+    aliases: [name]
+  iter_size:
+    description:
+      - Number of times to repeat the encryption step.
+      - This is B(not considered during idempotency checks).
+      - This is only used by the C(pyopenssl) backend, or when O(encryption_level=compatibility2022).
+      - When using it, the default is V(2048) for C(pyopenssl) and V(50000) for C(cryptography).
+    type: int
+  maciter_size:
+    description:
+      - Number of times to repeat the MAC step.
+      - This is B(not considered during idempotency checks).
+      - This is only used by the C(pyopenssl) backend. When using it, the default is V(1).
+    type: int
+  encryption_level:
+    description:
+      - Determines the encryption level used.
+      - V(auto) uses the default of the selected backend. For C(cryptography), this is what the cryptography library's specific
+        version considers the best available encryption.
+      - V(compatibility2022) uses compatibility settings for older software in 2022. This is only supported by the C(cryptography)
+        backend if cryptography >= 38.0.0 is available.
+      - B(Note) that this option is B(not used for idempotency).
+    choices:
+      - auto
+      - compatibility2022
+    default: auto
+    type: str
+    version_added: 2.8.0
+  passphrase:
+    description:
+      - The PKCS#12 password.
+      - B(Note:) PKCS12 encryption is typically not secure and should not be used as a security mechanism. If you need to
+        store or send a PKCS12 file safely, you should additionally encrypt it with something else. (L(Source,
+        https://cryptography.io/en/latest/hazmat/primitives/asymmetric/serialization/#cryptography.hazmat.primitives.serialization.pkcs12.serialize_key_and_certificates)).
+    type: str
+  path:
+    description:
+      - Filename to write the PKCS#12 file to.
+    type: path
+    required: true
+  privatekey_passphrase:
+    description:
+      - Passphrase source to decrypt any input private keys with.
+    type: str
+  privatekey_path:
+    description:
+      - File to read private key from.
+      - Mutually exclusive with O(privatekey_content).
+    type: path
+  privatekey_content:
+    description:
+      - Content of the private key file.
+      - Mutually exclusive with O(privatekey_path).
+    type: str
+    version_added: "2.3.0"
+  state:
+    description:
+      - Whether the file should exist or not. All parameters except O(path) are ignored when state is V(absent).
+    choices: [absent, present]
+    default: present
+    type: str
+  src:
+    description:
+      - PKCS#12 file path to parse.
+    type: path
+  backup:
+    description:
+      - Create a backup file including a timestamp so you can get the original output file back if you overwrote it with a
+        new one by accident.
+    type: bool
+    default: false
+  return_content:
+    description:
+      - If set to V(true), will return the (current or generated) PKCS#12's content as RV(pkcs12).
+    type: bool
+    default: false
+    version_added: "1.0.0"
+  select_crypto_backend:
+    description:
+      - Determines which crypto backend to use.
+      - The default choice is V(auto), which tries to use C(cryptography) if available, and falls back to C(pyopenssl). If
+        O(iter_size) is used together with O(encryption_level) is not V(compatibility2022), or if O(maciter_size) is used,
+        V(auto) will always result in C(pyopenssl) to be chosen for backwards compatibility.
+      - If set to V(pyopenssl), will try to use the L(pyOpenSSL,https://pypi.org/project/pyOpenSSL/) library.
+      - If set to V(cryptography), will try to use the L(cryptography,https://cryptography.io/) library.
+      - B(Note) that the V(pyopenssl) backend is deprecated and will be removed from community.crypto 3.0.0.
+    type: str
+    default: auto
+    choices: [auto, cryptography, pyopenssl]
+    version_added: 1.7.0
 seealso:
-- module: community.crypto.x509_certificate
-- module: community.crypto.openssl_csr
-- module: community.crypto.openssl_dhparam
-- module: community.crypto.openssl_privatekey
-- module: community.crypto.openssl_publickey
-'''
+  - module: community.crypto.x509_certificate
+  - module: community.crypto.openssl_csr
+  - module: community.crypto.openssl_dhparam
+  - module: community.crypto.openssl_privatekey
+  - module: community.crypto.openssl_publickey
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 - name: Generate PKCS#12 file
   community.crypto.openssl_pkcs12:
     action: export
@@ -158,9 +195,9 @@ EXAMPLES = r'''
     privatekey_path: /opt/certs/keys/key.pem
     certificate_path: /opt/certs/cert.pem
     other_certificates: /opt/certs/ca.pem
-    # Note that if /opt/certs/ca.pem contains multiple certificates,
-    # only the first one will be used. See the other_certificates_parse_all
-    # option for changing this behavior.
+  # Note that if /opt/certs/ca.pem contains multiple certificates,
+  # only the first one will be used. See the other_certificates_parse_all
+  # option for changing this behavior.
     state: present
 
 - name: Generate PKCS#12 file
@@ -173,12 +210,12 @@ EXAMPLES = r'''
     other_certificates_parse_all: true
     other_certificates:
       - /opt/certs/ca_bundle.pem
-        # Since we set other_certificates_parse_all to true, all
-        # certificates in the CA bundle are included and not just
-        # the first one.
+      # Since we set other_certificates_parse_all to true, all
+      # certificates in the CA bundle are included and not just
+      # the first one.
       - /opt/certs/intermediate.pem
-        # In case this file has multiple certificates in it,
-        # all will be included as well.
+      # In case this file has multiple certificates in it,
+      # all will be included as well.
     state: present
 
 - name: Change PKCS#12 file permission
@@ -216,33 +253,34 @@ EXAMPLES = r'''
   community.crypto.openssl_pkcs12:
     path: /opt/certs/ansible.p12
     state: absent
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 filename:
-    description: Path to the generate PKCS#12 file.
-    returned: changed or success
-    type: str
-    sample: /opt/certs/ansible.p12
+  description: Path to the generate PKCS#12 file.
+  returned: changed or success
+  type: str
+  sample: /opt/certs/ansible.p12
 privatekey:
-    description: Path to the TLS/SSL private key the public key was generated from.
-    returned: changed or success
-    type: str
-    sample: /etc/ssl/private/ansible.com.pem
+  description: Path to the TLS/SSL private key the public key was generated from.
+  returned: changed or success
+  type: str
+  sample: /etc/ssl/private/ansible.com.pem
 backup_file:
-    description: Name of backup file created.
-    returned: changed and if I(backup) is C(true)
-    type: str
-    sample: /path/to/ansible.com.pem.2019-03-09@11:22~
+  description: Name of backup file created.
+  returned: changed and if O(backup) is V(true)
+  type: str
+  sample: /path/to/ansible.com.pem.2019-03-09@11:22~
 pkcs12:
-    description: The (current or generated) PKCS#12's content Base64 encoded.
-    returned: if I(state) is C(present) and I(return_content) is C(true)
-    type: str
-    version_added: "1.0.0"
-'''
+  description: The (current or generated) PKCS#12's content Base64 encoded.
+  returned: if O(state) is V(present) and O(return_content) is V(true)
+  type: str
+  version_added: "1.0.0"
+"""
 
 import abc
 import base64
+import itertools
 import os
 import stat
 import traceback
@@ -278,11 +316,13 @@ from ansible_collections.community.crypto.plugins.module_utils.crypto.pem import
 
 MINIMAL_CRYPTOGRAPHY_VERSION = '3.0'
 MINIMAL_PYOPENSSL_VERSION = '0.15'
+MAXIMAL_PYOPENSSL_VERSION = '23.3.0'
 
 PYOPENSSL_IMP_ERR = None
 try:
     import OpenSSL
     from OpenSSL import crypto
+    from OpenSSL.crypto import load_pkcs12 as _load_pkcs12  # this got removed in pyOpenSSL 23.3.0
     PYOPENSSL_VERSION = LooseVersion(OpenSSL.__version__)
 except (ImportError, AttributeError):
     PYOPENSSL_IMP_ERR = traceback.format_exc()
@@ -302,6 +342,18 @@ except ImportError:
 else:
     CRYPTOGRAPHY_FOUND = True
 
+CRYPTOGRAPHY_COMPATIBILITY2022_ERR = None
+try:
+    from cryptography.hazmat.primitives import hashes
+    from cryptography.hazmat.primitives.serialization.pkcs12 import PBES
+    # Try to build encryption builder for compatibility2022
+    serialization.PrivateFormat.PKCS12.encryption_builder().key_cert_algorithm(PBES.PBESv1SHA1And3KeyTripleDESCBC).hmac_hash(hashes.SHA1())
+except Exception:
+    CRYPTOGRAPHY_COMPATIBILITY2022_ERR = traceback.format_exc()
+    CRYPTOGRAPHY_HAS_COMPATIBILITY2022 = False
+else:
+    CRYPTOGRAPHY_HAS_COMPATIBILITY2022 = True
+
 
 def load_certificate_set(filename, backend):
     '''
@@ -317,7 +369,7 @@ class PkcsError(OpenSSLObjectError):
 
 
 class Pkcs(OpenSSLObject):
-    def __init__(self, module, backend):
+    def __init__(self, module, backend, iter_size_default=2048):
         super(Pkcs, self).__init__(
             module.params['path'],
             module.params['state'],
@@ -328,10 +380,13 @@ class Pkcs(OpenSSLObject):
         self.action = module.params['action']
         self.other_certificates = module.params['other_certificates']
         self.other_certificates_parse_all = module.params['other_certificates_parse_all']
+        self.other_certificates_content = module.params['other_certificates_content']
         self.certificate_path = module.params['certificate_path']
+        self.certificate_content = module.params['certificate_content']
         self.friendly_name = module.params['friendly_name']
-        self.iter_size = module.params['iter_size'] or 2048
+        self.iter_size = module.params['iter_size'] or iter_size_default
         self.maciter_size = module.params['maciter_size'] or 1
+        self.encryption_level = module.params['encryption_level']
         self.passphrase = module.params['passphrase']
         self.pkcs12 = None
         self.privatekey_passphrase = module.params['privatekey_passphrase']
@@ -347,6 +402,15 @@ class Pkcs(OpenSSLObject):
         self.backup = module.params['backup']
         self.backup_file = None
 
+        if self.certificate_path is not None:
+            try:
+                with open(self.certificate_path, 'rb') as fh:
+                    self.certificate_content = fh.read()
+            except (IOError, OSError) as exc:
+                raise PkcsError(exc)
+        elif self.certificate_content is not None:
+            self.certificate_content = to_bytes(self.certificate_content)
+
         if self.privatekey_path is not None:
             try:
                 with open(self.privatekey_path, 'rb') as fh:
@@ -366,6 +430,13 @@ class Pkcs(OpenSSLObject):
                 self.other_certificates = [
                     load_certificate(other_cert, backend=self.backend) for other_cert in self.other_certificates
                 ]
+        elif self.other_certificates_content:
+            certs = self.other_certificates_content
+            if self.other_certificates_parse_all:
+                certs = list(itertools.chain.from_iterable(split_pem_list(content) for content in certs))
+            self.other_certificates = [
+                load_certificate(None, content=to_bytes(other_cert), backend=self.backend) for other_cert in certs
+            ]
 
     @abc.abstractmethod
     def generate_bytes(self, module):
@@ -422,11 +493,11 @@ class Pkcs(OpenSSLObject):
             elif bool(pkcs12_privatekey) != bool(self.privatekey_content):
                 return False
 
-            if (pkcs12_certificate is not None) and (self.certificate_path is not None):
+            if (pkcs12_certificate is not None) and (self.certificate_content is not None):
                 expected_cert = self._dump_certificate(self.pkcs12)
                 if pkcs12_certificate != expected_cert:
                     return False
-            elif bool(pkcs12_certificate) != bool(self.certificate_path):
+            elif bool(pkcs12_certificate) != bool(self.certificate_content):
                 return False
 
             if (pkcs12_other_certificates is not None) and (self.other_certificates is not None):
@@ -508,6 +579,8 @@ class Pkcs(OpenSSLObject):
 class PkcsPyOpenSSL(Pkcs):
     def __init__(self, module):
         super(PkcsPyOpenSSL, self).__init__(module, 'pyopenssl')
+        if self.encryption_level != 'auto':
+            module.fail_json(msg='The PyOpenSSL backend only supports encryption_level = auto')
 
     def generate_bytes(self, module):
         """Generate PKCS#12 file archive."""
@@ -516,8 +589,8 @@ class PkcsPyOpenSSL(Pkcs):
         if self.other_certificates:
             self.pkcs12.set_ca_certificates(self.other_certificates)
 
-        if self.certificate_path:
-            self.pkcs12.set_certificate(load_certificate(self.certificate_path, backend=self.backend))
+        if self.certificate_content:
+            self.pkcs12.set_certificate(load_certificate(None, content=self.certificate_content, backend=self.backend))
 
         if self.friendly_name:
             self.pkcs12.set_friendlyname(to_bytes(self.friendly_name))
@@ -573,7 +646,12 @@ class PkcsPyOpenSSL(Pkcs):
 
 class PkcsCryptography(Pkcs):
     def __init__(self, module):
-        super(PkcsCryptography, self).__init__(module, 'cryptography')
+        super(PkcsCryptography, self).__init__(module, 'cryptography', iter_size_default=50000)
+        if self.encryption_level == 'compatibility2022' and not CRYPTOGRAPHY_HAS_COMPATIBILITY2022:
+            module.fail_json(
+                msg='The installed cryptography version does not support encryption_level = compatibility2022.'
+                ' You need cryptography >= 38.0.0 and support for SHA1',
+                exception=CRYPTOGRAPHY_COMPATIBILITY2022_ERR)
 
     def generate_bytes(self, module):
         """Generate PKCS#12 file archive."""
@@ -585,21 +663,33 @@ class PkcsCryptography(Pkcs):
                 raise PkcsError(exc)
 
         cert = None
-        if self.certificate_path:
-            cert = load_certificate(self.certificate_path, backend=self.backend)
+        if self.certificate_content:
+            cert = load_certificate(None, content=self.certificate_content, backend=self.backend)
 
         friendly_name = to_bytes(self.friendly_name) if self.friendly_name is not None else None
 
         # Store fake object which can be used to retrieve the components back
         self.pkcs12 = (pkey, cert, self.other_certificates, friendly_name)
 
+        if not self.passphrase:
+            encryption = serialization.NoEncryption()
+        elif self.encryption_level == 'compatibility2022':
+            encryption = (
+                serialization.PrivateFormat.PKCS12.encryption_builder().
+                kdf_rounds(self.iter_size).
+                key_cert_algorithm(PBES.PBESv1SHA1And3KeyTripleDESCBC).
+                hmac_hash(hashes.SHA1()).
+                build(to_bytes(self.passphrase))
+            )
+        else:
+            encryption = serialization.BestAvailableEncryption(to_bytes(self.passphrase))
+
         return serialize_key_and_certificates(
             friendly_name,
             pkey,
             cert,
             self.other_certificates,
-            serialization.BestAvailableEncryption(to_bytes(self.passphrase))
-            if self.passphrase else serialization.NoEncryption(),
+            encryption,
         )
 
     def parse_bytes(self, pkcs12_content):
@@ -655,11 +745,18 @@ def select_backend(module, backend):
     if backend == 'auto':
         # Detection what is possible
         can_use_cryptography = CRYPTOGRAPHY_FOUND and CRYPTOGRAPHY_VERSION >= LooseVersion(MINIMAL_CRYPTOGRAPHY_VERSION)
-        can_use_pyopenssl = PYOPENSSL_FOUND and PYOPENSSL_VERSION >= LooseVersion(MINIMAL_PYOPENSSL_VERSION)
+        can_use_pyopenssl = (
+            PYOPENSSL_FOUND and
+            PYOPENSSL_VERSION >= LooseVersion(MINIMAL_PYOPENSSL_VERSION) and
+            PYOPENSSL_VERSION < LooseVersion(MAXIMAL_PYOPENSSL_VERSION)
+        )
 
         # If no restrictions are provided, first try cryptography, then pyOpenSSL
-        if module.params['iter_size'] is not None or module.params['maciter_size'] is not None:
-            # If iter_size or maciter_size is specified, use pyOpenSSL backend
+        if (
+            (module.params['iter_size'] is not None and module.params['encryption_level'] != 'compatibility2022')
+            or module.params['maciter_size'] is not None
+        ):
+            # If iter_size (for encryption_level != compatibility2022) or maciter_size is specified, use pyOpenSSL backend
             backend = 'pyopenssl'
         elif can_use_cryptography:
             backend = 'cryptography'
@@ -669,16 +766,19 @@ def select_backend(module, backend):
         # Success?
         if backend == 'auto':
             module.fail_json(msg=("Cannot detect any of the required Python libraries "
-                                  "cryptography (>= {0}) or PyOpenSSL (>= {1})").format(
+                                  "cryptography (>= {0}) or PyOpenSSL (>= {1}, < {2})").format(
                                       MINIMAL_CRYPTOGRAPHY_VERSION,
-                                      MINIMAL_PYOPENSSL_VERSION))
+                                      MINIMAL_PYOPENSSL_VERSION,
+                                      MAXIMAL_PYOPENSSL_VERSION))
 
     if backend == 'pyopenssl':
         if not PYOPENSSL_FOUND:
-            module.fail_json(msg=missing_required_lib('pyOpenSSL >= {0}'.format(MINIMAL_PYOPENSSL_VERSION)),
-                             exception=PYOPENSSL_IMP_ERR)
-        # module.deprecate('The module is using the PyOpenSSL backend. This backend has been deprecated',
-        #                  version='x.0.0', collection_name='community.crypto')
+            msg = missing_required_lib(
+                'pyOpenSSL >= {0}, < {1}'.format(MINIMAL_PYOPENSSL_VERSION, MAXIMAL_PYOPENSSL_VERSION)
+            )
+            module.fail_json(msg=msg, exception=PYOPENSSL_IMP_ERR)
+        module.deprecate('The module is using the PyOpenSSL backend. This backend has been deprecated',
+                         version='3.0.0', collection_name='community.crypto')
         return backend, PkcsPyOpenSSL(module)
     elif backend == 'cryptography':
         if not CRYPTOGRAPHY_FOUND:
@@ -694,9 +794,12 @@ def main():
         action=dict(type='str', default='export', choices=['export', 'parse']),
         other_certificates=dict(type='list', elements='path', aliases=['ca_certificates']),
         other_certificates_parse_all=dict(type='bool', default=False),
+        other_certificates_content=dict(type='list', elements='str'),
         certificate_path=dict(type='path'),
+        certificate_content=dict(type='str'),
         force=dict(type='bool', default=False),
         friendly_name=dict(type='str', aliases=['name']),
+        encryption_level=dict(type='str', choices=['auto', 'compatibility2022'], default='auto'),
         iter_size=dict(type='int'),
         maciter_size=dict(type='int'),
         passphrase=dict(type='str', no_log=True),
@@ -717,6 +820,8 @@ def main():
 
     mutually_exclusive = [
         ['privatekey_path', 'privatekey_content'],
+        ['certificate_path', 'certificate_content'],
+        ['other_certificates', 'other_certificates_content'],
     ]
 
     module = AnsibleModule(
