@@ -9,6 +9,10 @@ __metaclass__ = type
 
 DOCUMENTATION = r'''
     name: vmware_vm_inventory
+    deprecated:
+      removed_in: 7.0.0
+      why: This module has been moved to the L(new vmware.vmware collection,https://forum.ansible.com/t/5880)
+      alternative: Use P(vmware.vmware.vms#inventory) instead.
     short_description: VMware Guest inventory source
     author:
       - Abhijeet Kasurde (@Akasurde)
@@ -557,7 +561,7 @@ class BaseVMwareInventory:
             raise AnsibleError("Missing one of the following : hostname, username, password. Please read "
                                "the documentation for more information.")
 
-    def get_managed_objects_properties(self, vim_type, properties=None, resources=None, strict=False):  # noqa  # pylint: disable=too-complex
+    def get_managed_objects_properties(self, vim_type, properties=None, resources=None, strict=False):
         """
         Look up a Managed Object Reference in vCenter / ESXi Environment
         :param vim_type: Type of vim object e.g, for datacenter - vim.Datacenter
