@@ -3,7 +3,7 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 9.1.0
+# Version 9.3.0
 # Copyright (C) 2019-2024 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -374,8 +374,7 @@ error_info:
 import json
 import copy
 from ssl import SSLError
-from ansible_collections.dellemc.openmanage.plugins.module_utils.redfish import Redfish, redfish_auth_params
-from ansible.module_utils.basic import AnsibleModule
+from ansible_collections.dellemc.openmanage.plugins.module_utils.redfish import Redfish, RedfishAnsibleModule
 from ansible.module_utils.compat.version import LooseVersion
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
@@ -566,6 +565,10 @@ def perform_storage_volume_action(method, uri, session_obj, action, payload=None
     try:
         resp = session_obj.invoke_request(method, uri, data=payload)
         task_uri = resp.headers["Location"]
+        if not task_uri:
+            msg = resp.json_data["@Message.ExtendedInfo"][1]["Message"]
+            status_message = {"msg": msg}
+            return status_message
         return get_success_message(action, task_uri)
     except (HTTPError, URLError, SSLValidationError, ConnectionError,
             TypeError, ValueError) as err:
@@ -945,10 +948,7 @@ def main():
         "job_wait": {"required": False, "type": "bool", "default": False},
         "job_wait_timeout": {"required": False, "type": "int", "default": 1200}
     }
-
-    specs.update(redfish_auth_params)
-
-    module = AnsibleModule(
+    module = RedfishAnsibleModule(
         argument_spec=specs,
         mutually_exclusive=[['state', 'command'], ['volume_type', 'raid_type']],
         required_one_of=[['state', 'command']],
@@ -978,16 +978,19 @@ def main():
                 reboot_required = check_apply_time_supported_and_reboot_required(module, session_obj, controller_id, greater_version)
             if reboot_required:
                 perform_reboot(module, session_obj)
-            job_tracking_required = check_job_tracking_required(module, session_obj, reboot_required, controller_id, greater_version)
-            job_id = status_message.get("task_id")
-            job_url = MANAGER_JOB_ID_URI.format(job_id)
-            if job_tracking_required:
-                track_job(module, session_obj, job_id, job_url)
+            if status_message.get("task_id"):
+                job_tracking_required = check_job_tracking_required(module, session_obj, reboot_required, controller_id, greater_version)
+                job_id = status_message.get("task_id")
+                job_url = MANAGER_JOB_ID_URI.format(job_id)
+                if job_tracking_required and job_id:
+                    track_job(module, session_obj, job_id, job_url)
+                else:
+                    task_status = {"uri": job_url, "id": job_id}
+                    resp = session_obj.invoke_request("GET", job_url)
+                    job_data = strip_substr_dict(resp.json_data)
+                    module.exit_json(msg=status_message["msg"], task=task_status, job_status=job_data, changed=True)
             else:
-                task_status = {"uri": job_url, "id": job_id}
-                resp = session_obj.invoke_request("GET", job_url)
-                job_data = strip_substr_dict(resp.json_data)
-                module.exit_json(msg=status_message["msg"], task=task_status, job_status=job_data, changed=True)
+                module.exit_json(msg=status_message["msg"])
     except HTTPError as err:
         module.exit_json(msg=str(err), error_info=json.load(err), failed=True)
     except URLError as err:
